package com.menagerie.bakers

import androidx.compose.runtime.mutableStateOf
import com.menagerie.bakers.model.TTT
import com.russhwolf.settings.Settings

object SettingsKeys {
    const val THEME_KEY = "theme"
    const val SORT_BY_KEY = "sortBy"
    const val TTT_KEY = "ttt"
    const val AON_KEY = "aon"
    const val DESC_KEY = "desc"
    const val ANIM_KEY = "animate"
    const val DISCREET_KEY = "discreet"
    const val BETA_KEY = "betaRecipes"
}

object SettingsHolder {
    //Overall Settings Manager
    private val settings = Settings()

    //THEME
    private val initialTheme = when (settings.getStringOrNull(SettingsKeys.THEME_KEY)) {
        Theme.Light.name -> Theme.Light
        Theme.Dark.name -> Theme.Dark
        Theme.Auto.name -> Theme.Auto
        else -> Theme.Auto
    }

    var theme = mutableStateOf(initialTheme)


    val setTheme = {
        val newTheme = when (theme.value) {
            Theme.Auto -> Theme.Light
            Theme.Light -> Theme.Dark
            Theme.Dark -> Theme.Auto
        }
        theme.value = newTheme // Update the MutableState!
        settings.putString(SettingsKeys.THEME_KEY, newTheme.name) // Update storage
    }
    //END THEME

    //SORT BY
    private val initialSortBy = when (settings.getStringOrNull(SettingsKeys.SORT_BY_KEY)) {
        SortBy.Name.name -> SortBy.Name
        SortBy.Time.name -> SortBy.Time
        SortBy.Ingredients.name -> SortBy.Ingredients
        else -> SortBy.Name
    }

    var sortBy = mutableStateOf(initialSortBy)

    val setSortBy = {
        val newSort = when (sortBy.value) {
            SortBy.Name -> SortBy.Time
            SortBy.Time -> SortBy.Ingredients
            SortBy.Ingredients -> SortBy.Name
        }
        sortBy.value = newSort
        settings.putString(SettingsKeys.SORT_BY_KEY, newSort.name)
    }
    //END SORT BY

    //ANIMATE
    private val initialAnimate = (settings.getBoolean(SettingsKeys.ANIM_KEY, true))

    var animate = mutableStateOf(initialAnimate)

    val setAnimate = {
        animate.value  = !animate.value
        settings.putBoolean(SettingsKeys.ANIM_KEY, animate.value)
    }
    //END ANIMATE

    //DISCREET STEPS
    private val initialDiscreet = (settings.getBoolean(SettingsKeys.DISCREET_KEY, DisplayManager.device.value == Device.Android))

    var discreet = mutableStateOf(initialDiscreet)

    val setDiscreet = {
        discreet.value = !discreet.value
        settings.putBoolean(SettingsKeys.DISCREET_KEY, discreet.value)
    }
    //END DISCREET

    //BETA RECIPES
    private val initialBeta = (settings.getBoolean(SettingsKeys.BETA_KEY, false))

    var showBetaRecipes = mutableStateOf(initialBeta)

    val setShowBeta = {
        showBetaRecipes.value = !showBetaRecipes.value
        settings.putBoolean(SettingsKeys.BETA_KEY, showBetaRecipes.value)
    }
    //END BETA

    //TRIED, TESTED, or TRUE
    private val initialTTT = when (settings.getStringOrNull(SettingsKeys.TTT_KEY)) {

        TTT.TRIED.name -> TTT.TRIED
        TTT.TESTED.name -> TTT.TESTED
        TTT.TRUE.name -> TTT.TRUE
        else -> TTT.TESTED
    }

    var tttLevel = mutableStateOf(initialTTT)

    val setTTTLevel = {
        val newTTT = when (tttLevel.value) {
            TTT.TRIED -> TTT.TESTED
            TTT.TESTED -> TTT.TRUE
            TTT.TRUE -> TTT.TRIED
        }
        tttLevel.value = newTTT
        settings.putString(SettingsKeys.TTT_KEY, newTTT.name)
    }
    //END TTT LEVEL

    //Whether to use AND or OR in filtering TAGS specifically
    private val intialAndOrState = settings.getBoolean(SettingsKeys.AON_KEY, false)

    var AndOrState = mutableStateOf(intialAndOrState)

    val setAndOr = {
        AndOrState.value = !AndOrState.value
        settings.putBoolean(SettingsKeys.AON_KEY, AndOrState.value)
    }
    //END AON

    //DESC State
    private val initialDescent = settings.getBoolean(SettingsKeys.DESC_KEY, false)

    var descending = mutableStateOf(initialDescent)

    val setDescent = {
        descending.value = !descending.value
        settings.putBoolean(SettingsKeys.DESC_KEY, descending.value)
    }

}