package com.menagerie.bakers.view


import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material.MaterialTheme
import androidx.compose.material3.Button
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import bakersmenagerie.composeapp.generated.resources.Res
import bakersmenagerie.composeapp.generated.resources.chef
import bakersmenagerie.composeapp.generated.resources.history_android
import bakersmenagerie.composeapp.generated.resources.tune
import com.menagerie.bakers.Device
import com.menagerie.bakers.DisplayManager
import com.menagerie.bakers.Size
import com.menagerie.bakers.model.TipType
import com.menagerie.bakers.model.tipsTricksAndHelpers
import org.jetbrains.compose.resources.painterResource

@Composable
fun HomeScreen(
    onGo: () -> Unit,
    onSurprise: () -> Unit,
    onClose: () -> Unit,
) {
    val text = "Recipes"
    HeaderText(text, onGo, onSurprise, onClose)
}

@Composable
fun HeaderText(
    text: String,
    onGo: () -> Unit,
    onSurprise: () -> Unit,
    onClose: () -> Unit,
) {

    val header = when(DisplayManager.size.value){
        Size.Small -> MaterialTheme.typography.h2
        Size.Medium -> MaterialTheme.typography.h2
        Size.Large -> MaterialTheme.typography.h1
    }

    val lowHead = when(DisplayManager.size.value) {
        Size.Small -> MaterialTheme.typography.h4
        Size.Medium -> MaterialTheme.typography.h4
        Size.Large -> MaterialTheme.typography.h3
    }

    Box(
        modifier = Modifier
            .fillMaxSize()
    ) {
        Spacer(modifier = Modifier.fillMaxWidth())
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(top = 10.dp)
                .align(Alignment.Center),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Center,
        ) {
            TipTrickOrHelper(tipsTricksAndHelpers.random())
            Spacer(modifier = Modifier.weight(1f))
            Text (
                text = "Baker's Menagerie",
                style = header,
                textAlign = TextAlign.Center
            )
           Text (
                text = "An Allbright Family Cookbook",
                style = lowHead,
                textAlign = TextAlign.Center
            )
            Spacer(modifier = Modifier.weight(1f))
           Button(
                modifier = Modifier.padding(12.dp),
                onClick = onGo
            ) {
                Text(text = text)
            }
            if(DisplayManager.device.value == Device.Web)
            {
                Button(
                    modifier = Modifier.padding(12.dp),
                    onClick = onSurprise
                ){
                    Text("Surprise Me!")
                }
            }
            if(DisplayManager.device.value == Device.Desktop)
            {
                Button(modifier = Modifier.padding(12.dp),
                    onClick = onClose
                ) {
                    Text("Close")
                }
            }
        }
    }
}

@Composable
fun TipTrickOrHelper(string: String)
{
    val type: TipType
    val text: String

    if(string.contains("REMINDER"))
    {
        text = string.removePrefix("REMINDER-")
        type = TipType.Reminder
    }
    else if(string.contains("TIP"))
    {
        text = string.removePrefix("TIP-")
        type = TipType.Tip
    }
    else {
        text = string.removePrefix("TRICK-")
        type = TipType.Trick
    }

    Row {
        Icon(painter = painterResource(when (type) {
            TipType.Reminder -> Res.drawable.tune
            TipType.Tip -> Res.drawable.history_android
            TipType.Helper -> Res.drawable.chef
            TipType.Trick -> Res.drawable.chef
        }), contentDescription = "", modifier = Modifier.align(Alignment.CenterVertically))
        Text(text = text, modifier = Modifier.align(Alignment.CenterVertically))
    }
}