package com.menagerie.bakers.view.details

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.selection.SelectionContainer
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.rotate
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.style.LineHeightStyle
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import com.menagerie.bakers.DisplayManager
import com.menagerie.bakers.Size
import com.menagerie.bakers.model.Recipe

@Composable
fun InstructionItem(
    bgColor: Color,
    steps: List<String>,
    index: Int,
    slider: Float) {
    Box(modifier = Modifier.padding(start = 16.dp, end = 16.dp, top = 8.dp)) {
        Box(
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp)
                .border(
                    width = 2.dp,
                    color = if (bgColor != MaterialTheme.colorScheme.primaryContainer) {
                        if (index % 2 == 0) {
                            MaterialTheme.colorScheme.secondaryContainer
                        } else {
                            MaterialTheme.colorScheme.onBackground
                        }
                    } else
                        if (index % 2 == 0) {
                            MaterialTheme.colorScheme.background
                        } else {
                            MaterialTheme.colorScheme.onBackground
                        },
                    shape = RoundedCornerShape(35.dp)
                )
        ) {
            SelectionContainer {

                val style = when(DisplayManager.size.value) {
                    Size.Small -> MaterialTheme.typography.bodySmall
                    Size.Medium -> MaterialTheme.typography.bodyMedium
                    Size.Large -> MaterialTheme.typography.bodyLarge
                }

                Text(
                    text = scaleRecipeServingsInstructions(steps[index], slider),
                    style = style,
                    modifier = Modifier
                        .fillMaxWidth().fillMaxHeight()
                        .padding(start = 70.dp, end = 20.dp, top = 20.dp, bottom = 20.dp),
                )
            }
        }

        Box(
            modifier = Modifier
        ) {
            Box(
                modifier = Modifier
                    .size(50.dp)
                    .shadow(elevation = 10.dp, shape = CircleShape)
                    .background(
                        if (bgColor != MaterialTheme.colorScheme.primaryContainer) MaterialTheme.colorScheme.secondaryContainer else MaterialTheme.colorScheme.background,
                        CircleShape
                    ),
                contentAlignment = Alignment.Center
            ) {


                Text(
                    text = getOffsetIndex(steps, steps[index]),
                    style = MaterialTheme.typography.displayMedium.copy(
                        lineHeightStyle = LineHeightStyle(
                            alignment = LineHeightStyle.Alignment.Center,
                            trim = LineHeightStyle.Trim.None
                        )
                    ),
                    color = if (bgColor != MaterialTheme.colorScheme.primaryContainer) MaterialTheme.colorScheme.onSecondaryContainer else MaterialTheme.colorScheme.onBackground,
                    modifier = Modifier.padding(5.dp).rotate(-30f),
                    maxLines = 1,
                    overflow = TextOverflow.Ellipsis
                )
            }
        }
    }
}

fun getOffsetIndex(instructions: List<String>, s: String): String {

    var realIndex = 0

    for(str in instructions)
    {
        if(str.contains("HEADER-").not())
            realIndex++

        if(str == s)
            break
    }

    return realIndex.toString()

}
