package com.menagerie.bakers.view.util

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.MoreVert
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import com.menagerie.bakers.Device
import com.menagerie.bakers.DisplayManager
import com.menagerie.bakers.SettingsHolder
import com.menagerie.bakers.isDebug

@Composable
fun MainDropDown(
    modifier : Modifier,
    onRandom: () -> Unit,
    onBack: () -> Unit,
    onClose: () -> Unit,
) {
    var expanded by remember { mutableStateOf(false) }

    Box(
        modifier = modifier

    ) {
        IconButton(onClick = { expanded = !expanded }) {
            Icon(imageVector = Icons.Default.MoreVert, contentDescription = "More Options")
        }
        DropdownMenu(
            expanded = expanded,
            onDismissRequest = { expanded = false }
        ) {
            DropdownMenuItem(
                text = { Text("Current Theme: ".plus(SettingsHolder.theme.value.name)) },
                onClick = SettingsHolder.setTheme
            )

            DropdownMenuItem(
                text = { Text("Play Animations? ".plus(if(SettingsHolder.animate.value) "Yes" else "No")) },
                onClick = SettingsHolder.setAnimate
            )

            HorizontalDivider()


            if (DisplayManager.device.value != Device.Web)
                nonWebDropdown()

            HorizontalDivider()

            DropdownMenuItem(
                text = { Text("Random Filtered Recipe") },
                onClick = onRandom
            )
            when (DisplayManager.device.value) {

                Device.Android -> {}
                Device.Web, Device.Desktop -> {
                    HorizontalDivider()

                    DropdownMenuItem(
                        text = { Text("Go Back") },
                        onClick = onBack
                    )

                    if (DisplayManager.device.value == Device.Desktop)
                        DropdownMenuItem(
                            text = { Text("Close app") },
                            onClick = onClose
                        )
                }
            }
        }
    }
}

@Composable
fun innerDropDown(
    onDismiss: () -> Unit,
    expandedDebug: Boolean,
) {
    Column {
        DropdownMenu(
            expanded = expandedDebug,
            onDismissRequest = onDismiss
        ) {

            DropdownMenuItem(
                text = {
                    Text(
                        text = "Show Extra Discreet Recipe Steps?: ".plus(if(SettingsHolder.discreet.value) "Yes" else "No")
                    )
                },
                onClick = SettingsHolder.setDiscreet
            )

            DropdownMenuItem(
                text = {
                    Text(
                        text = "Help Us Improve! Show Only Recipes with Missing Info?: ".plus(
                            if(SettingsHolder.showBetaRecipes.value) "Yes" else "No"
                        )
                    )
                },
                onClick = SettingsHolder.setShowBeta
            )
            DropdownMenuItem(
                text = {
                    Text(text = "Show ".plus(SettingsHolder.tttLevel.value.name).plus(" recipes or better"))
                },
                onClick = SettingsHolder.setTTTLevel
            )
        }
    }
}

@Composable
fun nonWebDropdown() {

    var expandedFilter by remember { mutableStateOf(false) }

    DropdownMenuItem(
        text = {
            Row {
                Text(text = "Filter Options")
                Icon(imageVector = Icons.Default.ArrowDropDown, contentDescription = "")
            }
        },
        onClick = {expandedFilter = true}
    )

    if(expandedFilter)
        FilterDropdown(
            expanded = expandedFilter,
        ) {expandedFilter = false}

    var expandedDebug by remember { mutableStateOf(false) }

    if(isDebug)
    DropdownMenuItem(
        text = {
            Row {
                Text(text = "Debug Recipes")
                Icon(imageVector = Icons.Default.ArrowDropDown, contentDescription = "")
            }
        },
        onClick = {expandedDebug = true}
    )

    if(expandedDebug)
        innerDropDown(
            onDismiss = {expandedDebug = false},
            expandedDebug = expandedDebug,
        )
}

@Composable
fun FilterDropdown(
    expanded: Boolean,
    onDismiss: () -> Unit
){
    Column {
        DropdownMenu(
            onDismissRequest = onDismiss,
            expanded = expanded
        ) {
            DropdownMenuItem(
                text = { Text("Filter Style: ".plus(if (SettingsHolder.AndOrState.value) "OR" else "AND")) },
                onClick = SettingsHolder.setAndOr
            )
            DropdownMenuItem(
                text = { Text(text = "Sort By: ".plus(SettingsHolder.sortBy.value.name)) },
                onClick = SettingsHolder.setSortBy
            )
            DropdownMenuItem(
                text = { Text(text = "Sort Order: ".plus(if (SettingsHolder.descending.value) "DESC" else "ASC")) },
                onClick = SettingsHolder.setDescent
            )
        }
    }
}